@@ -96,6 +96,13 @@ Immediately delete the storage volume freeing its storage resources.
 The C<flags> parameter indicates any special action to be taken when
 deleting the volume.
 
+=item $vol->wipe($flags = 0)
+
+Clear the data in the storage volume to avoid future information
+leak. The C<flags> parameter indicates any special approach to be
+taken when wiping the data. It defaults to zero, which causes the
+volume to be filled with zeros.
+
 =item my %info = $vol->get_info()
 
 Retrieve live information about the storage volume. The returned
@@ -107,6 +114,18 @@ capacity for sparse, or grow-on-demand volumes. The allocation
 may also be larger than the capacity, if there is a metadata overhead
 for the volume format.
 
+=item $vol->download($st, $offset, $length);
+
+Download data from C<$vol> using the stream C<$st>. If C<$offset>
+and C<$length> are non-zero, then restrict data to the specified
+volume byte range.
+
+=item $vol->upload($st, $offset, $length);
+
+Upload data to C<$vol> using the stream C<$st>. If C<$offset>
+and C<$length> are non-zero, then restrict data to the specified
+volume byte range.
+
 =back
 
 =head1 CONSTANTS
